%define anolis_release 2

Summary:        Open an HTML file with automatic character set detection
Name:           perl-IO-HTML
Version:        1.004
Release:        %{anolis_release}%{?dist}

License:        (GPL-1.0-or-later OR Artistic-1.0-Perl) AND LicenseRef-Fedora-Public-Domain
URL:            https://metacpan.org/release/IO-HTML
Source0:        https://cpan.metacpan.org/authors/id/C/CJ/CJM/IO-HTML-%{version}.tar.gz

Patch0:         IO-HTML-1.004-Normalize-a-shebang.patch
BuildArch:      noarch

BuildRequires:  coreutils make
BuildRequires:  perl-generators perl-interpreter
BuildRequires:  perl(:VERSION) >= 5.8
BuildRequires:  perl(ExtUtils::MakeMaker) >= 6.76
BuildRequires:  perl(strict)
BuildRequires:  perl(warnings)
# For runtime:
BuildRequires:  perl(Carp)
BuildRequires:  perl(Encode) >= 2.10
BuildRequires:  perl(Exporter) >= 5.57
# For tests:
BuildRequires:  perl(File::Temp)
BuildRequires:  perl(Scalar::Util)
BuildRequires:  perl(Test::More) >= 0.88

%description
IO::HTML provides an easy way to open a file containing HTML while
automatically determining its encoding. It uses the HTML5 encoding sniffing
algorithm specified in section 8.2.2.1 of the draft standard.

The algorithm as implemented here is:
1. If the file begins with a byte order mark indicating UTF-16LE,
UTF-16BE, or UTF-8, then that is the encoding.

2. If the first $bytes_to_check bytes of the file contain a <meta>
tag that indicates the charset, and Encode recognizes the specified
charset name, then that is the encoding.
(This portion of the algorithm is implemented by find_charset_in.)

3. If the first $bytes_to_check bytes of the file are valid UTF-8
(with at least 1 non-ASCII character), then the encoding is UTF-8.

4. If all else fails, use the default character encoding. The HTML5
standard suggests the default encoding should be locale dependent,
but currently it is always cp1252 unless you set $IO::HTML::default_encoding
to a different value. Note: sniff_encoding does not apply this step;
only html_file does that.

%package doc
Summary:   Documents for %{name}
Requires:  %{name} = %{version}-%{release}

%description doc
Doc pages for %{name}.

%package tests
Summary:        Tests for %{name}
Requires:       %{name} = %{version}-%{release}
Requires:       perl-Test-Harness

%description tests
Tests from %{name}. Execute them
with "%{_libexecdir}/%{name}/test".

%prep
%autosetup -p1 -n IO-HTML-%{version}

# Help generators to recognize Perl scripts
for F in t/*.t; do
    perl -i -MConfig -ple 'print $Config{startperl} if $. == 1 && !s{\A#!\s*perl}{$Config{startperl}}' "$F"
    chmod +x "$F"
done

%build
perl Makefile.PL INSTALLDIRS=vendor NO_PACKLIST=1 NO_PERLLOCAL=1
%make_build

%install
%make_install
# Install tests
mkdir -p %{buildroot}%{_libexecdir}/%{name}
install -m 0644 -p t/* %{buildroot}%{_libexecdir}/%{name}
cat > %{buildroot}%{_libexecdir}/%{name}/test << 'EOF'
#!/bin/sh
cd %{_libexecdir}/%{name}
exec prove -I . -j "$(getconf _NPROCESSORS_ONLN)"
EOF
chmod +x %{buildroot}%{_libexecdir}/%{name}/test
install -m 0644 -p META.json %{buildroot}%{_libexecdir}/%{name}/
%{_fixperms} %{buildroot}/*

%check
make test

%files
%license LICENSE
%doc examples
%{perl_vendorlib}/*
%{_mandir}/man3/*

%files tests
%{_libexecdir}/%{name}

%files doc
%doc Changes README

%changelog
* Wed Apr 12 2023 Kun(llfl) <llfl@linux.alibaba.com> - 1.004-2
- optimize spec file

* Tue Jan 31 2023 Funda Wang <fundawang@yeah.net> - 1.004-1
- Import package for anolis 23
